/*
 * Copyright (c) 2016 Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


namespace EmailUI
{
    using System;
    using System.Collections.Generic;
    using Xamarin.Forms;

    /// <summary>
    /// The compose page of the EmailUI application.
    /// </summary>
    public class ComposePage : ContentPage
    {
        private string entry_address;
        private string entry_name;
        private string entry_name_text;
        private string entry_subject;
        private string entry_subject_text;
        private string entry_content;
        private string entry_content_text;

        /// <summary>
        /// Initializes a new instance of the <see cref="ComposePage"/> class.
        /// </summary>
        public ComposePage()
        {
            entry_address = "example@tizen.com";
            entry_name = "To";
            entry_subject = "Subject";
            entry_content = "Compose email";
            entry_name_text= "";
            entry_subject_text = "";
            entry_content_text = "";
            // The title of this page
            Title = "Compose";

            Appearing += (s, e) =>
            {
                App.ComposePage = this;
            };

            UpdateContent();

        }

        public void UpdateContent()
        {
            // Content view of this page.
            Content = new StackLayout
            {
                IsVisible = true,
                HorizontalOptions = LayoutOptions.FillAndExpand,
                VerticalOptions = LayoutOptions.FillAndExpand,

                // Set the Orientations of the StackLayout, the layout is vertical
                Orientation = StackOrientation.Vertical,
                Children =
                {
                    // Add new Label
                    new Entry()
                    {
                        HeightRequest = 0.07 * App.screenHeight,
                        Text = entry_address,
                        IsEnabled = false,
                        FontSize = 30
                    },
                    // Add new Label
                    new Entry()
                    {
                        HeightRequest = 0.07 * App.screenHeight,
                        Placeholder = entry_name,
                        Text=entry_name_text,
                        PlaceholderColor = Color.Gray,
                        FontSize = 30
                    },
                    // Add new Label
                    new Entry()
                    {
                        HeightRequest = 0.07 * App.screenHeight,
                        Placeholder = entry_subject,
                        Text = entry_subject_text,
                        PlaceholderColor = Color.Gray,
                        FontSize = 30
                    },
                    // Add new Label
                    new Entry()
                    {
                        HeightRequest = 0.07 * App.screenHeight,
                        Placeholder = entry_content,
                        Text = entry_content_text,
                        PlaceholderColor = Color.Gray,
                        FontSize = 30
                    }
                }
            };
        }

        public void SaveText()
        {
            entry_address = ((Entry)((StackLayout)this.Content).Children[0]).Text;
            entry_name_text = ((Entry)((StackLayout)this.Content).Children[1]).Text;
            entry_subject_text = ((Entry)((StackLayout)this.Content).Children[2]).Text;
            entry_content_text = ((Entry)((StackLayout)this.Content).Children[3]).Text;
        }
    }
}
